% [low,high,p]=bands(y)
%
% Given a signal y of length n, return:
%  low, a version of the signal containing only the low frequency parts of y
%  high, a version of the signal containing only the high frequency parts of y
%  p, an n*n matrix whose columns include different ranges of frequencies of y
% For example, p(:,j) is the signal y with just the lowest j frequency components.

function [low,high,p]=bands(y)

n=length(y);

[Q,C,S]=fourier(n);
c=C'*y; % compute the Fourier coefficients
s=S'*y;

% figure out the low frequency coefficients
clow=c.*((1:n/2+1)'<n/8);  % cut off the cosine coefficients after frequency n/8 (arbitrary point)
slow=s.*((1:n/2-1)'<n/8);  % and the same for sine coefficients

% figure out the high frequency coefficients
chigh=c-clow;  % the high frequencies are whatever is left
shigh=s-slow;  % ditto

% recombine these with the Fourier basis into low-pass and high-pass version of the input signal y
low=C*clow+S*slow;
high=C*chigh+S*shigh;

% finally do this cut-off for every frequency from 1 up to n
p=zeros(n,n);
for i=1:n
   cj=floor((i+1)/2);
   sj=floor(i/2);
   p(:,i)=C(:,1:cj)*c(1:cj)+S(:,1:sj)*s(1:sj);
end
