% [Q,C,S]=fourier(n)
%
% Compute the Fourier basis (in terms of cosines and sines) for signals of length n
% C has all the cosine terms in its columns, S has all the sine terms, and Q is
% simply the concatenation of the two.
% The columns are normalized, so that Q is an orthogonal matrix.

function [Q,C,S]=fourier(n)

C=zeros(n,n/2+1);
S=zeros(n,n/2-1);

for j=0:n/2
   C(:,j+1)=cos(2*pi*j*(0:n-1)/n)';
   C(:,j+1)=C(:,j+1)/norm(C(:,j+1));
end

for j=1:n/2-1
   S(:,j)=sin(2*pi*j*(0:n-1)/n)';
   S(:,j)=S(:,j)/norm(S(:,j));
end

Q=[C S];
